=============================
Django Categories v |version|
=============================

Contents:

.. toctree::
   :maxdepth: 2
   :glob:

   installation
   getting_started
   usage
   registering_models
   adding_the_fields
   reference/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

